@@ -12,7 +12,7 @@ import org.json.simple.JSONObject;
  */
 public class J4pVersionRequest extends J4pRequest {
 
-    protected J4pVersionRequest() {
+    public J4pVersionRequest() {
         super(J4pType.VERSION);
     }
 
@@ -21,11 +21,6 @@ public class J4pVersionRequest extends J4pRequest {
         return Collections.emptyList();
     }
 
-    @Override
-    JSONObject toJson() {
-        return super.toJson();
-    }
-
     @Override
     J4pVersionResponse createResponse(JSONObject pResponse) {
         return new J4pVersionResponse(this,pResponse);
