@@ -1,17 +1,19 @@
 package org.jmx4perl.backend;
 
-import java.io.IOException;
-import java.lang.management.ManagementFactory;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
-import java.util.*;
+import org.jmx4perl.JmxRequest;
+import org.jmx4perl.handler.JsonRequestHandler;
 
 import javax.management.*;
 import javax.naming.InitialContext;
 import javax.naming.NamingException;
-
-import org.jmx4perl.JmxRequest;
-import org.jmx4perl.handler.JsonRequestHandler;
+import java.io.IOException;
+import java.lang.management.ManagementFactory;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.util.Collections;
+import java.util.LinkedHashSet;
+import java.util.List;
+import java.util.Set;
 
 /*
  * jmx4perl - WAR Agent for exporting JMX via JSON
@@ -43,7 +45,7 @@ import org.jmx4perl.handler.JsonRequestHandler;
  * @author roland
  * @since Jun 15, 2009
  */
-public class MBeanServerHandler implements MBeanServerHandlerMBean,MBeanRegistration {
+public class MBeanServerHandler {
 
     // The MBeanServers to use
     // TODO: Dont cache them here ! Important for OSGi usage ...
@@ -52,28 +54,10 @@ public class MBeanServerHandler implements MBeanServerHandlerMBean,MBeanRegistra
 
     // Whether we are running under JBoss
     private boolean isJBoss = checkForClass("org.jboss.mx.util.MBeanServerLocator");
-
-    // Optional domain for registering this handler as a mbean
-    private String qualifier;
-
     // private boolean isWebsphere = checkForClass("com.ibm.websphere.management.AdminServiceFactory");
 
-
-    /**
-     * Create a new MBeanServer with no qualifier
-     */
     public MBeanServerHandler() {
-        this(null);
-    }
-
-    /**
-     * Create a new MBeanServer handler who is responsible for managing multiple intra VM {@link MBeanServer} at once
-     *
-     * @param pQualifier optional qualifier used for registering this object as an MBean (can be null)
-     */
-    public MBeanServerHandler(String pQualifier) {
         initMBeanServers();
-        qualifier = pQualifier;
     }
 
     /**
@@ -316,71 +300,4 @@ public class MBeanServerHandler implements MBeanServerHandlerMBean,MBeanRegistra
     }
 
 
-    public String mBeanServersInfo() {
-        StringBuffer ret = new StringBuffer();
-        Set<MBeanServer> servers = getMBeanServers();
-
-        ret.append("Found ").append(servers.size()).append(" MBeanServers\n");
-        for (MBeanServer s : servers) {
-            ret.append("    ")
-                    .append("++ ")
-                    .append(s.toString())
-                    .append(": default domain = ")
-                    .append(s.getDefaultDomain())
-                    .append(", ")
-                    .append(s.getMBeanCount())
-                        .append(" MBeans\n");
-
-            ret.append("        Domains:\n");
-            boolean javaLangFound = false;
-            for (String d : s.getDomains()) {
-                if ("java.lang".equals(d)) {
-                    javaLangFound = true;
-                }
-                appendDomainInfo(ret, s, d);
-            }
-            if (!javaLangFound) {
-                // JBoss fails to list java.lang in its domain list
-                appendDomainInfo(ret,s,"java.lang");
-            }
-        }
-        ret.append("\n");
-        ret.append("Platform MBeanServer: ")
-                .append(ManagementFactory.getPlatformMBeanServer())
-                .append("\n");
-        return ret.toString();
-    }
-
-    private void appendDomainInfo(StringBuffer pRet, MBeanServer pServer, String pDomain) {
-        try {
-            pRet.append("         == ").append(pDomain).append("\n");
-            Set<ObjectInstance> beans = pServer.queryMBeans(new ObjectName(pDomain + ":*"),null);
-            for (ObjectInstance o : beans) {
-                String n = o.getObjectName().getCanonicalKeyPropertyListString();
-                pRet.append("              ").append(n).append("\n");
-            }
-        } catch (MalformedObjectNameException e) {
-            // Shouldnt happen
-            pRet.append("              INTERNAL ERROR: ").append(e).append("\n");
-        }
-    }
-
-    // ==============================================================================================
-    // Needed for providing the name for our MBean
-    public ObjectName preRegister(MBeanServer server, ObjectName name) throws MalformedObjectNameException {
-        return new ObjectName(getObjectName());
-    }
-
-    public String getObjectName() {
-        return OBJECT_NAME + (qualifier != null ? "," + qualifier : "");
-    }
-
-    public void postRegister(Boolean registrationDone) {
-    }
-
-    public void preDeregister() {
-    }
-
-    public void postDeregister() {
-    }
 }
