@@ -32,6 +32,8 @@ import java.lang.reflect.InvocationTargetException;
  */
 
 /**
+ * Handler for dealing with write request.
+ *
  * @author roland
  * @since Jun 12, 2009
  */
@@ -101,5 +103,16 @@ public class WriteHandler extends JsonRequestHandler {
         server.setAttribute(request.getObjectName(),attribute);
         return values[1];
     }
+
+    /**
+     * The old value is returned directly, hence we do not want any path conversion
+     * on this value
+     *
+     * @return false;
+     */
+    @Override
+    public boolean useReturnValueWithPath() {
+        return false;
+    }
 }
 
